==> gamgi_0.14.8.orig.tar.gz: gamgi0.14.8/src/gtk/plane/gamgi_gtk_plane_modify.h <==
/*************************************************
 *
 * $GAMGI/src/gtk/plane/gamgi_gtk_plane_modify.h
 *
 * Copyright (C) 2006 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static gamgi_bool static_find (gamgi_plane *plane, 
gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3);

static void static_remove (gamgi_plane *plane);

static GtkWidget *static_atom (GtkWidget *dialog);

static void static_end_atom (GtkWidget *dialog);

static gamgi_enum static_class (gamgi_window *window);

static void static_start_cell (gamgi_window *window);

static void static_start_atom (gamgi_window *window);

static void static_instance (GtkWidget *widget, void *data);

static void static_start_position (gamgi_window *window);

static void static_autonomy (GtkWidget *widget, void *data);

static void static_reference (GtkWidget *widget, void *data);

static void static_start_polygon (gamgi_window *window);

static void static_start_projection (gamgi_window *window);

static void static_nodes (GtkWidget *widget, void *data);

static void static_cell (GtkWidget *widget, void *data);

static void static_vectors (GtkWidget *widget, void *data);

static void static_reset (gamgi_window *window);

static void static_global (GtkWidget *widget, void *data);

static gamgi_bool static_ok_cell (gamgi_plane *plane, gamgi_cell **cell,
gamgi_window *window);

static gamgi_bool static_ok_atoms (gamgi_plane *plane, 
gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3, 
gamgi_window *window);

static gamgi_bool static_ok_polygon (gamgi_cell *cell, int *hkl,
gamgi_enum vectors, gamgi_enum *type, gamgi_projection *projection,
gamgi_enum *autonomy, double *thickness, int *order, gamgi_window *window);

static gamgi_bool static_ok_projection (gamgi_enum *autonomy,
gamgi_projection *projection, gamgi_enum *type, gamgi_window *window);

static gamgi_bool static_ok_position (gamgi_enum autonomy,
double *euler, double *origin, gamgi_window *window);

static gamgi_bool static_ok_view (float *red, float *green,
float *blue, double *scale, gamgi_window *window);

static void static_ok (GtkWidget *widget, void *data);

static void static_init (gamgi_window *window);

static void static_press (gamgi_object *object, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_plane_modify_press (gamgi_window *window_mouse,
GdkEventButton *event, int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_plane_modify (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Cleaned.

 *************
 * Rationale *
 *************/

==> gamgi_0.15.orig.tar.gz: gamgi0.15/src/gtk/plane/gamgi_gtk_plane_modify.h <==
/*************************************************
 *
 * $GAMGI/src/gtk/plane/gamgi_gtk_plane_modify.h
 *
 * Copyright (C) 2006 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static gamgi_bool static_find (gamgi_plane *plane, 
gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3);

static void static_remove (gamgi_plane *plane);

static GtkWidget *static_atom (GtkWidget *dialog);

static void static_end_atom (GtkWidget *dialog);

static gamgi_enum static_class (gamgi_window *window);

static void static_start_cell (gamgi_window *window);

static void static_start_atom (gamgi_window *window);

static void static_instance (GtkWidget *widget, void *data);

static void static_start_position (gamgi_window *window);

static void static_autonomy (GtkWidget *widget, void *data);

static void static_reference (GtkWidget *widget, void *data);

static void static_start_scope (gamgi_window *window);

static void static_start_projection (gamgi_window *window);

static void static_nodes (GtkWidget *widget, void *data);

static void static_cell (GtkWidget *widget, void *data);

static void static_vectors (GtkWidget *widget, void *data);

static void static_reset (gamgi_window *window);

static void static_global (GtkWidget *widget, void *data);

static gamgi_bool static_ok_cell (gamgi_plane *plane, gamgi_cell **cell,
gamgi_window *window);

static gamgi_bool static_ok_atoms (gamgi_plane *plane, 
gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3, 
gamgi_window *window);

static gamgi_bool static_ok_scope (gamgi_cell *cell, int *hkl,
gamgi_enum vectors, gamgi_enum *type, gamgi_projection *projection,
gamgi_enum *autonomy, double *thickness, int *order, gamgi_window *window);

static gamgi_bool static_ok_projection (gamgi_enum *autonomy,
gamgi_projection *projection, gamgi_enum *type, gamgi_window *window);

static gamgi_bool static_ok_position (gamgi_enum autonomy,
double *euler, double *origin, gamgi_window *window);

static gamgi_bool static_ok_view (float *red, float *green,
float *blue, double *scale, gamgi_window *window);

static void static_ok (GtkWidget *widget, void *data);

static void static_init (gamgi_window *window);

static void static_press (gamgi_object *object, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_plane_modify_press (gamgi_window *window_mouse,
GdkEventButton *event, int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_plane_modify (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Cleaned.

 *************
 * Rationale *
 *************/
